@@ -6,15 +6,19 @@ use warnings;
 use WWW::Shopify;
 
 package WWW::Shopify::Model::Order::LineItem::Property;
-use parent "WWW::Shopify::Model::Item";
+use parent "WWW::Shopify::Model::NestedItem";
 
-sub stats($) { return {
+my $fields; sub fields { return $fields; } 
+BEGIN { $fields = {
 	"name" => new WWW::Shopify::Field::String(),
 	"value" => new WWW::Shopify::Field::String()};
 }
 
 sub plural() { return 'properties'; }
+sub creatable { return undef; }
+sub updatable { return undef; }
+sub deletable { return undef; }
 
-eval(WWW::Shopify::Model::Item::generate_accessors(__PACKAGE__)); die $@ if $@;
+eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
 1
