@@ -13,10 +13,12 @@ BEGIN { $fields = {
 	"author" => new WWW::Shopify::Field::String::Name(),
 	"body_html" => new WWW::Shopify::Field::Text::HTML(),
 	"summary_html" => new WWW::Shopify::Field::Text::HTML(),
+	"template_suffix" => new WWW::Shopify::Field::String(),
 	"title" => new WWW::Shopify::Field::String::Words(1, 3),
-	"handle" => new WWW::Shopify::Field::String::Words(1),
+	"handle" => new WWW::Shopify::Field::String::Handle(),
 	"metafields" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Metafield"),
 	"id" => new WWW::Shopify::Field::Identifier(),
+	"shop_id" => new WWW::Shopify::Field::Relation::ReferenceOne("WWW::Shopify::Model::Shop"),
 	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
 	"updated_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
 	"published_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00'),
