@@ -8,7 +8,8 @@ use WWW::Shopify;
 package WWW::Shopify::Model::ProductSearchEngine;
 use parent "WWW::Shopify::Model::Item";
 
-sub stats($) { return {
+my $fields; sub fields { return $fields; } 
+BEGIN { $fields = {
 	"created_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
 	"name" => new WWW::Shopify::Field::Identifier::String()};
 }
@@ -17,6 +18,6 @@ sub creatable($) { return undef; }
 sub updatable($) { return undef; }
 sub deletable($) { return undef; }
 
-eval(WWW::Shopify::Model::Item::generate_accessors(__PACKAGE__)); die $@ if $@;
+eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
 1;
